@@ -96,12 +96,12 @@ class PerpetualStreamConnection(Generic[StreamMsgResponseType]):
         await self.close()
 
     async def __await_impl__(self):
-        extra_headers = {
-            RequestHeader.USER_AGENT.value: USER_AGENT,
+        extra_headers: dict[str, str] = {
+            RequestHeader.USER_AGENT: USER_AGENT,
         }
 
         if self.__api_key is not None:
-            extra_headers[RequestHeader.API_KEY.value] = self.__api_key
+            extra_headers[RequestHeader.API_KEY] = self.__api_key
 
         self.__websocket = await websockets.connect(self.__stream_url, extra_headers=extra_headers)
 
